@@ -61,6 +61,7 @@ class MMSBM:
     pr = None
     likelihood = None
     prediction_matrix = None
+    rng = None
 
     def __init__(
         self,
@@ -79,9 +80,9 @@ class MMSBM:
         self.debug = debug
 
         # Initiate the general random state
-        rng = np.random.default_rng(seed)
+        self.rng = np.random.default_rng(seed)
         # Initiate the child random states
-        ss = rng.bit_generator._seed_seq
+        ss = self.rng.bit_generator._seed_seq
         self.child_states = ss.spawn(sampling)
 
         self.logger = logging.getLogger("MMSBM")
@@ -136,9 +137,7 @@ class MMSBM:
         rng = np.random.default_rng(seed)
 
         # Generate random (but normalized) inits
-        temp = rng.random((self.p + 1, self.user_groups))
-        theta = normalize_with_d(temp, self.d0)
-
+        theta = normalize_with_d(rng.random((self.p + 1, self.user_groups)), self.d0)
         eta = normalize_with_d(rng.random((self.m + 1, self.item_groups)), self.d1)
         pr = normalize_with_self(rng.random((self.user_groups, self.item_groups, self.r + 1)))
 
@@ -299,7 +298,7 @@ class MMSBM:
             test_indices = [
                 a
                 for a in temp.groupby(temp.columns[0], as_index=False)
-                .apply(get_n_per_group, n=items_per_fold)
+                .apply(get_n_per_group, n=items_per_fold, rng=self.rng)
                 .values
             ]
             test_indices = [a for b in test_indices for a in b if str(a) != "0"]
